@@ -4,14 +4,9 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $Re0 = {
-    'from'       => qr/[<]?(?>postmaster[@]ezweb[.]ne[.]jp)[>]?/i,
-    'subject'    => qr/\AMail System Error - Returned Mail\z/,
-    'received'   => qr/\Afrom[ ](?:.+[.])?ezweb[.]ne[.]jp[ ]/,
-    'message-id' => qr/[@].+[.]ezweb[.]ne[.]jp[>]\z/,
-};
-my $Re1 = {
-    'begin'    => qr{\A(?:
+my $Indicators = __PACKAGE__->INDICATORS;
+my $MarkingsOf = {
+    'message' => qr{\A(?:
          The[ ]user[(]s[)][ ]
         |Your[ ]message[ ]
         |Each[ ]of[ ]the[ ]following
@@ -20,14 +15,11 @@ my $Re1 = {
     }x,
     'rfc822'   => qr#\A(?:[-]{50}|Content-Type:[ ]*message/rfc822)#,
     'boundary' => qr/\A__SISIMAI_PSEUDO_BOUNDARY__\z/,
-    'endof'    => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
 };
-my $ReFailure = {
-    #'notaccept' => [ qr/The following recipients did not receive this message:/ ],
-    'mailboxfull' => [
-        qr/The user[(]s[)] account is temporarily over quota/,
-    ],
-    'suspend' => [
+my $ReFailures = {
+    #'notaccept'  => [qr/The following recipients did not receive this message:/],
+    'mailboxfull' => [qr/The user[(]s[)] account is temporarily over quota/],
+    'suspend'     => [
         # http://www.naruhodo-au.kddi.com/qa3429203.html
         # The recipient may be unpaid user...?
         qr/The user[(]s[)] account is disabled[.]/,
@@ -38,16 +30,11 @@ my $ReFailure = {
         # Remote host is not responding.
         qr/Your message was not delivered within /,
     ],
-    'onhold' => [
-        qr/Each of the following recipients was rejected by a remote mail server/,
-    ],
+    'onhold' => [qr/Each of the following recipients was rejected by a remote mail server/],
 };
-my $Indicators = __PACKAGE__->INDICATORS;
 
 sub headerlist  { return ['X-SPASIGN'] }
-sub pattern     { return $Re0 }
 sub description { 'au EZweb: http://www.au.kddi.com/mobile/' }
-
 sub scan {
     # Detect an error from EZweb
     # @param         [Hash] mhead       Message headers of a bounce email
@@ -73,17 +60,16 @@ sub scan {
     #   Received: from ezweb.ne.jp (wmflb12na02.ezweb.ne.jp [222.15.69.197])
     #   Received: from nmomta.auone-net.jp ([aaa.bbb.ccc.ddd]) by ...
     #
-    $match++ if $mhead->{'from'}     =~ $Re0->{'from'};
-    $match++ if $mhead->{'subject'}  =~ $Re0->{'subject'};
-    $match++ if grep { $_ =~ $Re0->{'received'} } @{ $mhead->{'received'} };
+    $match++ if index($mhead->{'from'}, 'Postmaster@ezweb.ne.jp') > -1;
+    $match++ if $mhead->{'subject'} eq 'Mail System Error - Returned Mail';
+    $match++ if grep { index($_, 'ezweb.ne.jp (EZweb Mail) with') > -1 } @{ $mhead->{'received'} };
     if( defined $mhead->{'message-id'} ) {
-        $match++ if $mhead->{'message-id'} =~ $Re0->{'message-id'};
+        $match++ if substr($mhead->{'message-id'}, -13, 13) eq '.ezweb.ne.jp>';
     }
     return undef if $match < 2;
 
     require Sisimai::String;
     require Sisimai::Address;
-
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
     my @hasdivided = split("\n", $$mbody);
     my $rfc822part = '';    # (String) message/rfc822-headers part
@@ -100,21 +86,21 @@ sub scan {
         my $b0 = Sisimai::MIME->boundary($mhead->{'content-type'}, 1);
         if( length $b0 ) {
             # Convert to regular expression
-            $Re1->{'boundary'} = qr/\A\Q$b0\E\z/;
+            $MarkingsOf->{'boundary'} = qr/\A\Q$b0\E\z/;
         }
     }
-    my @rxmessages = (); map { push @rxmessages, @{ $ReFailure->{ $_ } } } (keys %$ReFailure);
+    my @rxmessages = (); map { push @rxmessages, @{ $ReFailures->{ $_ } } } (keys %$ReFailures);
 
     for my $e ( @hasdivided ) {
-        # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
+        # Read each line between the start of the message and the start of rfc822 part.
         unless( $readcursor ) {
             # Beginning of the bounce message or delivery status part
-            $readcursor |= $Indicators->{'deliverystatus'} if $e =~ $Re1->{'begin'};
+            $readcursor |= $Indicators->{'deliverystatus'} if $e =~ $MarkingsOf->{'message'};
         }
 
         unless( $readcursor & $Indicators->{'message-rfc822'} ) {
             # Beginning of the original message part
-            if( $e =~ $Re1->{'rfc822'} || $e =~ $Re1->{'boundary'} ) {
+            if( $e =~ $MarkingsOf->{'rfc822'} || $e =~ $MarkingsOf->{'boundary'} ) {
                 $readcursor |= $Indicators->{'message-rfc822'};
                 next;
             }
@@ -147,9 +133,9 @@ sub scan {
             #    <<< 550 <******@ezweb.ne.jp>: User unknown
             $v = $dscontents->[-1];
 
-            if( $e =~ m/\A[<]([^ ]+[@][^ ]+)[>]\z/ ||
-                $e =~ m/\A[<]([^ ]+[@][^ ]+)[>]:?(.*)\z/ ||
-                $e =~ m/\A[ \t]+Recipient: [<]([^ ]+[@][^ ]+)[>]/ ) {
+            if( $e =~ /\A[<]([^ ]+[@][^ ]+)[>]\z/ ||
+                $e =~ /\A[<]([^ ]+[@][^ ]+)[>]:?(.*)\z/ ||
+                $e =~ /\A[ \t]+Recipient: [<]([^ ]+[@][^ ]+)[>]/ ) {
 
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
@@ -162,27 +148,27 @@ sub scan {
                     $v->{'recipient'} = $r;
                     $recipients++;
                 }
-            } elsif( $e =~ m/\A[Ss]tatus:[ ]*(\d[.]\d+[.]\d+)/ ) {
+            } elsif( $e =~ /\AStatus:[ ]*(\d[.]\d+[.]\d+)/ ) {
                 # Status: 5.1.1
                 # Status:5.2.0
                 # Status: 5.1.0 (permanent failure)
                 $v->{'status'} = $1;
 
-            } elsif( $e =~ m/\A[Aa]ction:[ ]*(.+)\z/ ) {
+            } elsif( $e =~ /\AAction:[ ]*(.+)\z/ ) {
                 # Action: failed
                 $v->{'action'} = lc $1;
 
-            } elsif( $e =~ m/\A[Rr]emote-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
+            } elsif( $e =~ /\ARemote-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
                 # Remote-MTA: DNS; mx.example.jp
                 $v->{'rhost'} = lc $1;
 
-            } elsif( $e =~ m/\A[Ll]ast-[Aa]ttempt-[Dd]ate:[ ]*(.+)\z/ ) {
+            } elsif( $e =~ /\ALast-Attempt-Date:[ ]*(.+)\z/ ) {
                 # Last-Attempt-Date: Fri, 14 Feb 2014 12:30:08 -0500
                 $v->{'date'} = $1;
 
             } else {
                 next if Sisimai::String->is_8bit(\$e);
-                if( $e =~ m/\A[ \t]+[>]{3}[ \t]+([A-Z]{4})/ ) {
+                if( $e =~ /\A[ \t]+[>]{3}[ \t]+([A-Z]{4})/ ) {
                     #    >>> RCPT TO:<******@ezweb.ne.jp>
                     $v->{'command'} = $1;
 
@@ -205,13 +191,15 @@ sub scan {
         if( exists $e->{'alterrors'} && length $e->{'alterrors'} ) {
             # Copy alternative error message
             $e->{'diagnosis'} ||= $e->{'alterrors'};
-            if( $e->{'diagnosis'} =~ m/\A[-]+/ || $e->{'diagnosis'} =~ m/__\z/ ) {
+            if( index($e->{'diagnosis'}, '-') == 0 || substr($e->{'diagnosis'}, -2, 2) eq '__' ) {
                 # Override the value of diagnostic code message
                 $e->{'diagnosis'} = $e->{'alterrors'} if length $e->{'alterrors'};
             }
             delete $e->{'alterrors'};
         }
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
+        $e->{'agent'} = __PACKAGE__->smtpagent;
+
 
         if( defined $mhead->{'x-spasign'} && $mhead->{'x-spasign'} eq 'NG' ) {
             # Content-Type: text/plain; ..., X-SPASIGN: NG (spamghetti, au by EZweb)
@@ -226,9 +214,9 @@ sub scan {
 
             } else {
                 # SMTP command is not RCPT
-                SESSION: for my $r ( keys %$ReFailure ) {
+                SESSION: for my $r ( keys %$ReFailures ) {
                     # Verify each regular expression of session errors
-                    PATTERN: for my $rr ( @{ $ReFailure->{ $r } } ) {
+                    PATTERN: for my $rr ( @{ $ReFailures->{ $r } } ) {
                         # Check each regular expression
                         next(PATTERN) unless $e->{'diagnosis'} =~ $rr;
                         $e->{'reason'} = $r;
@@ -237,16 +225,13 @@ sub scan {
                 }
             }
         }
+        next if $e->{'reason'};
 
-        unless( $e->{'reason'} ) {
-            # The value of "reason" is not set yet.
-            unless( $e->{'recipient'} =~ m/[@]ezweb[.]ne[.]jp\z/ ) {
-                # Deal as "userunknown" when the domain part of the recipient
-                # is "ezweb.ne.jp".
-                $e->{'reason'} = 'userunknown';
-            }
-        }
-        $e->{'agent'} = __PACKAGE__->smtpagent;
+        # The value of "reason" is not set yet.
+        next if substr($e->{'recipient'}, -12, -12) eq '@ezweb.ne.jp';
+        # Deal as "userunknown" when the domain part of the recipient
+        # is "ezweb.ne.jp".
+        $e->{'reason'} = 'userunknown';
     }
     $rfc822part = Sisimai::RFC5322->weedout($rfc822list);
     return { 'ds' => $dscontents, 'rfc822' => $$rfc822part };
@@ -294,7 +279,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
