@@ -4,55 +4,36 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $ReE = {
-    'from'      => qr/[@].+[.]mail[.]ru[>]?/,
+my $Indicators = __PACKAGE__->INDICATORS;
+my $StartingOf = {
+    'deliverystatus' => ['Content-type: message/delivery-status'],
+    'endof'          => ['__END_OF_EMAIL_MESSAGE__'],
 };
-my $Re0 = {
-    'from'      => qr/\AMail Delivery System/,
-    'subject'   => qr{(?:
-         Mail[ ]delivery[ ]failed(:[ ]returning[ ]message[ ]to[ ]sender)?
-        |Warning:[ ]message[ ].+[ ]delayed[ ]+
-        |Delivery[ ]Status[ ]Notification
-        |Mail[ ]failure
-        |Message[ ]frozen
-        |error[(]s[)][ ]in[ ]forwarding[ ]or[ ]filtering
-        )
-    }x,
-    #'message-id'=> qr/\A[<]\w+[-]\w+[-]\w+[@].+\z/,
-    # Message-Id: <E1P1YNN-0003AD-Ga@example.org>
-};
-
-# Error text regular expressions which defined in exim/src/deliver.c
-#
-# deliver.c:6292| fprintf(f,
-# deliver.c:6293|"This message was created automatically by mail delivery software.\n");
-# deliver.c:6294|        if (to_sender)
-# deliver.c:6295|          {
-# deliver.c:6296|          fprintf(f,
-# deliver.c:6297|"\nA message that you sent could not be delivered to one or more of its\n"
-# deliver.c:6298|"recipients. This is a permanent error. The following address(es) failed:\n");
-# deliver.c:6299|          }
-# deliver.c:6300|        else
-# deliver.c:6301|          {
-# deliver.c:6302|          fprintf(f,
-# deliver.c:6303|"\nA message sent by\n\n  <%s>\n\n"
-# deliver.c:6304|"could not be delivered to one or more of its recipients. The following\n"
-# deliver.c:6305|"address(es) failed:\n", sender_address);
-# deliver.c:6306|          }
-#
-# deliver.c:6423|          if (bounce_return_body) fprintf(f,
-# deliver.c:6424|"------ This is a copy of the message, including all the headers. ------\n");
-# deliver.c:6425|          else fprintf(f,
-# deliver.c:6426|"------ This is a copy of the message's headers. ------\n");
-my $Re1 = {
-    'alias'  => qr/\A([ ]+an[ ]undisclosed[ ]address)\z/,
-    'frozen' => qr/\AMessage .+ (?:has been frozen|was frozen on arrival)/,
-    'rfc822' => qr{\A(?:
-         [-]+[ ]This[ ]is[ ]a[ ]copy[ ]of[ ](?:the|your)[ ]message.+headers[.][ ][-]+
-        |Content-Type:[ ]*message/rfc822
-        )\z
-    }x,
-    'begin'  => qr{\A(?>
+my $MarkingsOf = {
+    # Error text regular expressions which defined in exim/src/deliver.c
+    #
+    # deliver.c:6292| fprintf(f,
+    # deliver.c:6293|"This message was created automatically by mail delivery software.\n");
+    # deliver.c:6294|        if (to_sender)
+    # deliver.c:6295|          {
+    # deliver.c:6296|          fprintf(f,
+    # deliver.c:6297|"\nA message that you sent could not be delivered to one or more of its\n"
+    # deliver.c:6298|"recipients. This is a permanent error. The following address(es) failed:\n");
+    # deliver.c:6299|          }
+    # deliver.c:6300|        else
+    # deliver.c:6301|          {
+    # deliver.c:6302|          fprintf(f,
+    # deliver.c:6303|"\nA message sent by\n\n  <%s>\n\n"
+    # deliver.c:6304|"could not be delivered to one or more of its recipients. The following\n"
+    # deliver.c:6305|"address(es) failed:\n", sender_address);
+    # deliver.c:6306|          }
+    #
+    # deliver.c:6423|          if (bounce_return_body) fprintf(f,
+    # deliver.c:6424|"------ This is a copy of the message, including all the headers. ------\n");
+    # deliver.c:6425|          else fprintf(f,
+    # deliver.c:6426|"------ This is a copy of the message's headers. ------\n");
+    'alias'   => qr/\A([ ]+an undisclosed address)\z/,
+    'message' => qr{\A(?>
          This[ ]message[ ]was[ ]created[ ]automatically[ ]by[ ]mail[ ]delivery[ ]software[.]
         |A[ ]message[ ]that[ ]you[ ]sent[ ]was[ ]rejected[ ]by[ ]the[ ]local[ ]scanning[ ]code
         |A[ ]message[ ]that[ ]you[ ]sent[ ]contained[ ]one[ ]or[ ]more[ ]recipient[ ]addresses[ ]
@@ -60,11 +41,15 @@ my $Re1 = {
         |The[ ].+[ ]router[ ]encountered[ ]the[ ]following[ ]error[(]s[)]:
         )
     }x,
-    'deliverystatus' => qr|\AContent-type: message/delivery-status|,
-    'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
+    'frozen'  => qr/\AMessage .+ (?:has been frozen|was frozen on arrival)/,
+    'rfc822'  => qr{\A(?:
+         [-]+[ ]This[ ]is[ ]a[ ]copy[ ]of[ ](?:the|your)[ ]message.+headers[.][ ][-]+
+        |Content-Type:[ ]*message/rfc822
+        )\z
+    }x,
 };
 
-my $ReCommand = [
+my $ReCommands = [
     # transports/smtp.c:564|  *message = US string_sprintf("SMTP error from remote mail server after %s%s: "
     # transports/smtp.c:837|  string_sprintf("SMTP error from remote mail server after RCPT TO:<%s>: "
     qr/SMTP error from remote (?:mail server|mailer) after ([A-Za-z]{4})/,
@@ -72,11 +57,10 @@ my $ReCommand = [
     qr/LMTP error after ([A-Za-z]{4})/,
     qr/LMTP error after end of ([A-Za-z]{4})/,
 ];
-
-# find exim/ -type f -exec grep 'message = US' {} /dev/null \;
-my $ReFailure = {
+my $ReFailures = {
+    # find exim/ -type f -exec grep 'message = US' {} /dev/null \;
     # route.c:1158|  DEBUG(D_uid) debug_printf("getpwnam() returned NULL (user not found)\n");
-    'userunknown' => qr/user[ ]not[ ]found/x,
+    'userunknown' => qr/user not found/,
     # transports/smtp.c:3524|  addr->message = US"all host address lookups failed permanently";
     # routers/dnslookup.c:331|  addr->message = US"all relevant MX records point to non-existent hosts";
     # route.c:1826|  uschar *message = US"Unrouteable address";
@@ -91,7 +75,7 @@ my $ReFailure = {
     # transports/appendfile.c:2567|  addr->user_message = US"mailbox is full";
     # transports/appendfile.c:3049|  addr->message = string_sprintf("mailbox is full "
     # transports/appendfile.c:3050|  "(quota exceeded while writing to file %s)", filename);
-    'mailboxfull' => qr/(?:mailbox[ ]is[ ]full:?|error:[ ]quota[ ]exceed)/x,
+    'mailboxfull' => qr/(?:mailbox is full:?|error: quota exceed)/,
     # routers/dnslookup.c:328|  addr->message = US"an MX or SRV record indicated no SMTP service";
     # transports/smtp.c:3502|  addr->message = US"no host found for existing SMTP connection";
     'notaccept' => qr{(?:
@@ -120,19 +104,19 @@ my $ReFailure = {
         )
     }x,
     # deliver.c:5425|  new->message = US"Too many \"Received\" headers - suspected mail loop";
-    'contenterror' => qr/Too[ ]many[ ]["]Received["][ ]headers/x,
+    'contenterror' => qr/Too many ["]Received["] headers/,
 };
 
-# retry.c:902|  addr->message = (addr->message == NULL)? US"retry timeout exceeded" :
-# deliver.c:7475|  "No action is required on your part. Delivery attempts will continue for\n"
-# smtp.c:3508|  US"retry time not reached for any host after a long failure period" :
-# smtp.c:3508|  US"all hosts have been failing for a long time and were last tried "
-#                 "after this message arrived";
-# deliver.c:7459|  print_address_error(addr, f, US"Delay reason: ");
-# deliver.c:7586|  "Message %s has been frozen%s.\nThe sender is <%s>.\n", message_id,
-# receive.c:4021|  moan_tell_someone(freeze_tell, NULL, US"Message frozen on arrival",
-# receive.c:4022|  "Message %s was frozen on arrival by %s.\nThe sender is <%s>.\n",
-my $ReDelayed = qr{(?:
+my $ReDelaying = qr{(?:
+    # retry.c:902|  addr->message = (addr->message == NULL)? US"retry timeout exceeded" :
+    # deliver.c:7475|  "No action is required on your part. Delivery attempts will continue for\n"
+    # smtp.c:3508|  US"retry time not reached for any host after a long failure period" :
+    # smtp.c:3508|  US"all hosts have been failing for a long time and were last tried "
+    #                 "after this message arrived";
+    # deliver.c:7459|  print_address_error(addr, f, US"Delay reason: ");
+    # deliver.c:7586|  "Message %s has been frozen%s.\nThe sender is <%s>.\n", message_id,
+    # receive.c:4021|  moan_tell_someone(freeze_tell, NULL, US"Message frozen on arrival",
+    # receive.c:4022|  "Message %s was frozen on arrival by %s.\nThe sender is <%s>.\n",
      retry[ ]timeout[ ]exceeded
     |No[ ]action[ ]is[ ]required[ ]on[ ]your[ ]part
     |retry[ ]time[ ]not[ ]reached[ ]for[ ]any[ ]host[ ]after[ ]a[ ]long[ ]failure[ ]period
@@ -141,13 +125,10 @@ my $ReDelayed = qr{(?:
     |Message[ ].+[ ](?:has[ ]been[ ]frozen|was[ ]frozen[ ]on[ ]arrival[ ]by[ ])
     )
 }x;
-my $Indicators = __PACKAGE__->INDICATORS;
 
 # X-Failed-Recipients: kijitora@example.ed.jp
 sub headerlist  { return ['X-Failed-Recipients'] }
-sub pattern     { return $Re0 }
 sub description { 'Exim' }
-
 sub scan {
     # Detect an error from Exim
     # @param         [Hash] mhead       Message headers of a bounce email
@@ -165,9 +146,19 @@ sub scan {
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
 
-    return undef if     $mhead->{'from'}    =~ $ReE->{'from'};
-    return undef unless $mhead->{'from'}    =~ $Re0->{'from'};
-    return undef unless $mhead->{'subject'} =~ $Re0->{'subject'};
+    #'message-id'=> qr/\A[<]\w+[-]\w+[-]\w+[@].+\z/,
+    # Message-Id: <E1P1YNN-0003AD-Ga@example.org>
+    return undef if $mhead->{'from'} =~/[@].+[.]mail[.]ru[>]?/;
+    return undef unless index($mhead->{'from'}, 'Mail Delivery System') == 0;
+    return undef unless $mhead->{'subject'} =~ qr{(?:
+         Mail[ ]delivery[ ]failed(:[ ]returning[ ]message[ ]to[ ]sender)?
+        |Warning:[ ]message[ ].+[ ]delayed[ ]+
+        |Delivery[ ]Status[ ]Notification
+        |Mail[ ]failure
+        |Message[ ]frozen
+        |error[(]s[)][ ]in[ ]forwarding[ ]or[ ]filtering
+        )
+    }x;
 
     require Sisimai::String;
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
@@ -192,20 +183,20 @@ sub scan {
     }
 
     for my $e ( @hasdivided ) {
-        # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
-        last if $e =~ $Re1->{'endof'};
+        # Read each line between the start of the message and the start of rfc822 part.
+        last if $e eq $StartingOf->{'endof'}->[0];
 
         unless( $readcursor ) {
             # Beginning of the bounce message or delivery status part
-            if( $e =~ $Re1->{'begin'} ) {
+            if( $e =~ $MarkingsOf->{'message'} ) {
                 $readcursor |= $Indicators->{'deliverystatus'};
-                next unless $e =~ $Re1->{'frozen'};
+                next unless $e =~ $MarkingsOf->{'frozen'};
             }
         }
 
         unless( $readcursor & $Indicators->{'message-rfc822'} ) {
             # Beginning of the original message part
-            if( $e =~ $Re1->{'rfc822'} ) {
+            if( $e =~ $MarkingsOf->{'rfc822'} ) {
                 $readcursor |= $Indicators->{'message-rfc822'};
                 next;
             }
@@ -235,9 +226,9 @@ sub scan {
             #    host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
             $v = $dscontents->[-1];
 
-            if( $e =~ m/\A[ \t]{2}([^ \t]+[@][^ \t]+[.]?[a-zA-Z]+)(:.+)?\z/ ||
-                $e =~ m/\A[ \t]{2}[^ \t]+[@][^ \t]+[.][a-zA-Z]+[ ]<(.+?[@].+?)>:.+\z/ ||
-                $e =~ $Re1->{'alias'} ) {
+            if( $e =~ /\A[ \t]{2}([^ \t]+[@][^ \t]+[.]?[a-zA-Z]+)(:.+)?\z/ ||
+                $e =~ /\A[ \t]{2}[^ \t]+[@][^ \t]+[.][a-zA-Z]+[ ]<(.+?[@].+?)>:.+\z/ ||
+                $e =~ $MarkingsOf->{'alias'} ) {
                 #   kijitora@example.jp
                 #   sabineko@example.jp: forced freeze
                 #   mikeneko@example.jp <nekochan@example.org>: ...
@@ -253,7 +244,7 @@ sub scan {
                     $v = $dscontents->[-1];
                 }
 
-                if( $e =~ m/\A[ \t]+[^ \t]+[@][^ \t]+[.][a-zA-Z]+[ ]<(.+?[@].+?)>:.+\z/ ) {
+                if( $e =~ /\A[ \t]+[^ \t]+[@][^ \t]+[.][a-zA-Z]+[ ]<(.+?[@].+?)>:.+\z/ ) {
                     # parser.c:743| while (bracket_count-- > 0) if (*s++ != '>')
                     # parser.c:744|   {
                     # parser.c:745|   *errorptr = s[-1] == 0
@@ -268,8 +259,8 @@ sub scan {
                 $v->{'recipient'} = $r;
                 $recipients++;
 
-            } elsif( $e =~ m/\A[ ]+[(]generated[ ]from[ ](.+)[)]\z/ ||
-                     $e =~ m/\A[ ]+generated[ ]by[ ]([^ \t]+[@][^ \t]+)/ ) {
+            } elsif( $e =~ /\A[ ]+[(]generated[ ]from[ ](.+)[)]\z/ ||
+                     $e =~ /\A[ ]+generated[ ]by[ ]([^ \t]+[@][^ \t]+)/ ) {
                 #     (generated from kijitora@example.jp)
                 #  pipe to |/bin/echo "Some pipe output"
                 #    generated by userx@myhost.test.ex
@@ -278,7 +269,7 @@ sub scan {
             } else {
                 next unless length $e;
 
-                if( $e =~ $Re1->{'frozen'} ) {
+                if( $e =~ $MarkingsOf->{'frozen'} ) {
                     # Message *** has been frozen by the system filter.
                     # Message *** was frozen on arrival by ACL.
                     $v->{'alterrors'} .= $e.' ';
@@ -288,34 +279,34 @@ sub scan {
                         # --NNNNNNNNNN-eximdsn-MMMMMMMMMM
                         # Content-type: message/delivery-status
                         # ...
-                        if( $e =~ m/\A[Rr]eporting-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
+                        if( $e =~ /\AReporting-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
                             # Reporting-MTA: dns; mx.example.jp
                             $v->{'lhost'} = $1;
 
-                        } elsif( $e =~ m/\A[Aa]ction:[ ]*(.+)\z/ ) {
+                        } elsif( $e =~ /\AAction:[ ]*(.+)\z/ ) {
                             # Action: failed
                             $v->{'action'} = lc $1;
 
-                        } elsif( $e =~ m/\A[Ss]tatus:[ ]*(\d[.]\d+[.]\d+)/ ) {
+                        } elsif( $e =~ /\AStatus:[ ]*(\d[.]\d+[.]\d+)/ ) {
                             # Status: 5.0.0
                             $v->{'status'} = $1;
 
-                        } elsif( $e =~ m/\A[Dd]iagnostic-[Cc]ode:[ ]*(.+?);[ ]*(.+)\z/ ) {
+                        } elsif( $e =~ /\ADiagnostic-Code:[ ]*(.+?);[ ]*(.+)\z/ ) {
                             # Diagnostic-Code: SMTP; 550 5.1.1 <userunknown@example.jp>... User Unknown
                             $v->{'spec'} = uc $1;
                             $v->{'diagnosis'} = $2;
 
-                        } elsif( $e =~ m/\A[Ff]inal-[Rr]ecipient:[ ]*(?:RFC|rfc)822;[ ]*(.+)\z/ ) {
+                        } elsif( $e =~ /\AFinal-Recipient:[ ]*(?:RFC|rfc)822;[ ]*(.+)\z/ ) {
                             # Final-Recipient: rfc822;|/bin/echo "Some pipe output"
                             my $c = $1;
-                            $v->{'spec'} ||= $c =~ m/[@]/ ? 'SMTP' : 'X-UNIX';
+                            $v->{'spec'} ||= index($c, '@') > -1 ? 'SMTP' : 'X-UNIX';
 
                         } else {
                             # Error message ?
                             unless( $havepassed->{'deliverystatus'} ) {
                                 # Content-type: message/delivery-status
-                                $havepassed->{'deliverystatus'} = 1 if $e =~ $Re1->{'deliverystatus'};
-                                $v->{'alterrors'} .= $e.' ' if $e =~ m/\A[ ]+/;
+                                $havepassed->{'deliverystatus'} = 1 if index($e, $StartingOf->{'deliverystatus'}) == 0;
+                                $v->{'alterrors'} .= $e.' ' if index($e, ' ') == 0;
                             }
                         }
                     } else {
@@ -333,7 +324,7 @@ sub scan {
                                 $v->{'diagnosis'} = $e;
 
                             } else {
-                                next unless $e =~ m/\A[ ]{4}/;
+                                next unless index($e, '    ') == 0;
                                 $v->{'alterrors'} .= $e.' ';
                             }
                         }
@@ -348,7 +339,7 @@ sub scan {
         for my $q ( @$dscontents ) {
             # Replace the recipient address with the value of "alias"
             next unless $q->{'alias'};
-            if( length($q->{'recipient'}) == 0 || $q->{'recipient'} !~ m/[@]/ ) {
+            if( length($q->{'recipient'}) == 0 || index($q->{'recipient'}, '@') == -1 ) {
                 # The value of "recipient" is empty or does not include "@"
                 $q->{'recipient'} = $q->{'alias'};
             }
@@ -361,7 +352,7 @@ sub scan {
             map { $_ =~ s/\A[ ]+//; $_ =~ s/[ ]+\z// } @rcptinhead;
             $recipients = scalar @rcptinhead;
 
-            for my $e ( @rcptinhead ) {
+            while( my $e = shift @rcptinhead ) {
                 # Insert each recipient address into @$dscontents
                 $dscontents->[-1]->{'recipient'} = $e;
                 next if scalar @$dscontents == $recipients;
@@ -374,12 +365,11 @@ sub scan {
     if( scalar @{ $mhead->{'received'} } ) {
         # Get the name of local MTA
         # Received: from marutamachi.example.org (c192128.example.net [192.0.2.128])
-        $localhost0 = $1 if $mhead->{'received'}->[-1] =~ m/from[ \t]([^ ]+) /;
+        $localhost0 = $1 if $mhead->{'received'}->[-1] =~ /from[ \t]([^ ]+) /;
     }
 
     require Sisimai::SMTP::Reply;
     require Sisimai::SMTP::Status;
-
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
         $e->{'agent'}   = __PACKAGE__->smtpagent;
@@ -414,7 +404,7 @@ sub scan {
             # Copy alternative error message
             $e->{'diagnosis'} ||= $e->{'alterrors'};
 
-            if( $e->{'diagnosis'} =~ m/\A[-]+/ || $e->{'diagnosis'} =~ m/__\z/ ) {
+            if( index($e->{'diagnosis'}, '-') == 0 || substr($e->{'diagnosis'}, -2, 2) eq '__' ) {
                 # Override the value of diagnostic code message
                 $e->{'diagnosis'} = $e->{'alterrors'} if length $e->{'alterrors'};
 
@@ -433,14 +423,12 @@ sub scan {
             delete $e->{'alterrors'};
         }
         $e->{'diagnosis'} =  Sisimai::String->sweep($e->{'diagnosis'});
-        $e->{'diagnosis'} =~ s{\b__.+\z}{};
+        $e->{'diagnosis'} =~ s/\b__.+\z//;
 
         unless( $e->{'rhost'} ) {
             # Get the remote host name
-            if( $e->{'diagnosis'} =~ m/host[ \t]+([^ \t]+)[ \t]\[.+\]:[ \t]/ ) {
-                # host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
-                $e->{'rhost'} = $1;
-            }
+            # host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
+            $e->{'rhost'} = $1 if $e->{'diagnosis'} =~ /host[ \t]+([^ \t]+)[ \t]\[.+\]:[ \t]/;
 
             unless( $e->{'rhost'} ) {
                 if( scalar @{ $mhead->{'received'} } ) {
@@ -453,7 +441,7 @@ sub scan {
 
         unless( $e->{'command'} ) {
             # Get the SMTP command name for the session
-            SMTP: for my $r ( @$ReCommand ) {
+            SMTP: for my $r ( @$ReCommands ) {
                 # Verify each regular expression of SMTP commands
                 next unless $e->{'diagnosis'} =~ $r;
                 $e->{'command'} = uc $1;
@@ -461,7 +449,7 @@ sub scan {
             }
 
             # Detect the reason of bounce
-            if( $e->{'command'} =~ m/\A(?:HELO|EHLO)\z/ ) {
+            if( $e->{'command'} eq 'HELO' || $e->{'command'} eq 'EHLO' ) {
                 # HELO | Connected to 192.0.2.135 but my name was rejected.
                 $e->{'reason'} = 'blocked';
 
@@ -472,16 +460,16 @@ sub scan {
 
             } else {
                 # Verify each regular expression of session errors
-                SESSION: for my $r ( keys %$ReFailure ) {
+                SESSION: for my $r ( keys %$ReFailures ) {
                     # Check each regular expression
-                    next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
+                    next unless $e->{'diagnosis'} =~ $ReFailures->{ $r };
                     $e->{'reason'} = $r;
                     last;
                 }
 
                 unless( $e->{'reason'} ) {
                     # The reason "expired"
-                    $e->{'reason'} = 'expired' if $e->{'diagnosis'} =~ $ReDelayed;
+                    $e->{'reason'} = 'expired' if $e->{'diagnosis'} =~ $ReDelaying;
                 }
             }
         }
@@ -502,21 +490,23 @@ sub scan {
             my $r1 = 0; # First character of SMTP reply code as integer
             my $v1 = 0;
 
-            # "Status:" field did not exist in the bounce message
-            unless( length $sv ) {
-                # Check SMTP reply code
-                if( length $rv ) {
-                    # Generate pseudo DSN code from SMTP reply code
-                    $r1 = substr($rv, 0, 1);
-                    if( $r1 == 4 ) {
-                        # Get the internal DSN(temporary error)
-                        $sv = Sisimai::SMTP::Status->code($e->{'reason'}, 1);
+            FIND_CODE: while(1) {
+                # "Status:" field did not exist in the bounce message
+                last if length $sv;
+                last unless length $rv;
 
-                    } elsif( $r1 == 5 ) {
-                        # Get the internal DSN(permanent error)
-                        $sv = Sisimai::SMTP::Status->code($e->{'reason'}, 0);
-                    }
+                # Check SMTP reply code
+                # Generate pseudo DSN code from SMTP reply code
+                $r1 = substr($rv, 0, 1);
+                if( $r1 == 4 ) {
+                    # Get the internal DSN(temporary error)
+                    $sv = Sisimai::SMTP::Status->code($e->{'reason'}, 1);
+
+                } elsif( $r1 == 5 ) {
+                    # Get the internal DSN(permanent error)
+                    $sv = Sisimai::SMTP::Status->code($e->{'reason'}, 0);
                 }
+                last;
             }
 
             $s1  = substr($sv, 0, 1) if length $sv;
@@ -530,7 +520,7 @@ sub scan {
 
             } else {
                 # Neither Status nor SMTP reply code exist
-                if( $e->{'reason'} =~ m/\A(?:expired|mailboxfull)/ ) {
+                if( $e->{'reason'} eq 'expired' || $e->{'reason'} eq 'mailboxfull' ) {
                     # Set pseudo DSN (temporary error)
                     $sv = Sisimai::SMTP::Status->code($e->{'reason'}, 1);
 
@@ -590,7 +580,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
