@@ -4,23 +4,20 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $Re0 = {
-    'subject'    => qr/Undeliverable:/,
-    'received'   => qr/.+[.](?:outbound[.]protection|prod)[.]outlook[.]com\b/,
-    'message-id' => qr/.+[.](?:outbound[.]protection|prod)[.]outlook[.]com\b/,
+my $Indicators = __PACKAGE__->INDICATORS;
+my $StartingOf = {
+    'rfc822' => ['Content-Type: message/rfc822'],
+    'error'  => ['Diagnostic information for administrators:'],
+    'eoerr'  => ['Original message headers:'],
 };
-my $Re1 = {
-    'begin'  => qr{\A(?:
+my $MarkingsOf = {
+    'message' => qr{\A(?:
          Delivery[ ]has[ ]failed[ ]to[ ]these[ ]recipients[ ]or[ ]groups:
         |.+[ ]rejected[ ]your[ ]message[ ]to[ ]the[ ]following[ ]e[-]?mail[ ]addresses:
         )
     }x,
-    'error'  => qr/\ADiagnostic information for administrators:\z/,
-    'eoerr'  => qr/\AOriginal message headers:\z/,
-    'rfc822' => qr|\AContent-Type: message/rfc822\z|,
-    'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
 };
-my $CodeTable = {
+my $StatusList = {
     # https://support.office.com/en-us/article/Email-non-delivery-reports-in-Office-365-51daa6b9-2e35-49c4-a0c9-df85bf8533c3
     qr/\A4[.]4[.]7\z/        => 'expired',
     qr/\A4[.]7[.]26\z/       => 'securityerror',
@@ -46,7 +43,6 @@ my $CodeTable = {
     qr/\A5[.]7[.]6[1-4]\d\z/ => 'blocked',
     qr/\A5[.]7[.]7[0-4]\d\z/ => 'toomanyconn',
 };
-my $Indicators = __PACKAGE__->INDICATORS;
 
 sub headerlist  { 
     # X-MS-Exchange-Message-Is-Ndr:
@@ -66,9 +62,7 @@ sub headerlist  {
         'X-MS-Exchange-Transport-CrossTenantHeadersStamped',
     ]
 }
-sub pattern     { return $Re0 }
 sub description { 'Microsoft Office 365: http://office.microsoft.com/' }
-
 sub scan {
     # Detect an error from Microsoft Office 365
     # @param         [Hash] mhead       Message headers of a bounce email
@@ -86,8 +80,9 @@ sub scan {
     my $mhead = shift // return undef;
     my $mbody = shift // return undef;
     my $match = 0;
+    my $tryto = qr/.+[.](?:outbound[.]protection|prod)[.]outlook[.]com\b/;
 
-    $match++ if $mhead->{'subject'} =~ $Re0->{'subject'};
+    $match++ if index($mhead->{'subject'}, 'Undeliverable:') > -1;
     $match++ if $mhead->{'x-ms-exchange-message-is-ndr'};
     $match++ if $mhead->{'x-microsoft-antispam-prvs'};
     $match++ if $mhead->{'x-exchange-antispam-report-test'};
@@ -95,10 +90,10 @@ sub scan {
     $match++ if $mhead->{'x-ms-exchange-crosstenant-originalarrivaltime'};
     $match++ if $mhead->{'x-ms-exchange-crosstenant-fromentityheader'};
     $match++ if $mhead->{'x-ms-exchange-transport-crosstenantheadersstamped'};
-    $match++ if grep { $_ =~ $Re0->{'received'} } @{ $mhead->{'received'} };
+    $match++ if grep { $_ =~ $tryto } @{ $mhead->{'received'} };
     if( defined $mhead->{'message-id'} ) {
         # Message-ID: <00000000-0000-0000-0000-000000000000@*.*.prod.outlook.com>
-        $match++ if $mhead->{'message-id'} =~ $Re0->{'message-id'};
+        $match++ if $mhead->{'message-id'} =~ $tryto;
     }
     return undef if $match < 2;
 
@@ -115,10 +110,10 @@ sub scan {
     my $v = undef;
 
     for my $e ( @hasdivided ) {
-        # Read each line between $Re1->{'begin'} and $Re1->{'rfc822'}.
+        # Read each line between the start of the message and the start of rfc822 part.
         unless( $readcursor ) {
             # Beginning of the bounce message or delivery status part
-            if( $e =~ $Re1->{'begin'} ) {
+            if( $e =~ $MarkingsOf->{'message'} ) {
                 $readcursor |= $Indicators->{'deliverystatus'};
                 next;
             }
@@ -126,7 +121,7 @@ sub scan {
 
         unless( $readcursor & $Indicators->{'message-rfc822'} ) {
             # Beginning of the original message part
-            if( $e =~ $Re1->{'rfc822'} ) {
+            if( $e eq $StartingOf->{'rfc822'}->[0] ) {
                 $readcursor |= $Indicators->{'message-rfc822'};
                 next;
             }
@@ -152,7 +147,7 @@ sub scan {
             # nding the message.
             $v = $dscontents->[-1];
 
-            if( $e =~ m/\A.+[@].+[<]mailto:(.+[@].+)[>]\z/ ) {
+            if( $e =~ /\A.+[@].+[<]mailto:(.+[@].+)[>]\z/ ) {
                 # kijitora@example.com<mailto:kijitora@example.com>
                 if( length $v->{'recipient'} ) {
                     # There are multiple recipient addresses in the message body.
@@ -162,7 +157,7 @@ sub scan {
                 $v->{'recipient'} = $1;
                 $recipients++;
 
-            } elsif( $e =~ m/\AGenerating server: (.+)\z/ ) {
+            } elsif( $e =~ /\AGenerating server: (.+)\z/ ) {
                 # Generating server: FFFFFFFFFFFF.e0.prod.outlook.com
                 $connheader->{'lhost'} = lc $1;
 
@@ -171,36 +166,36 @@ sub scan {
                     # After "Original message headers:"
                     if( $htmlbegins ) {
                         # <html> .. </html>
-                        $htmlbegins = 0 if $e =~ m|\A[<]/html[>]|;
+                        $htmlbegins = 0 if index($e, '</html>') == 0;
                         next;
                     }
 
-                    if( $e =~ m/\A[Aa]ction:[ ]*(.+)\z/ ) {
+                    if( $e =~ /\AAction:[ ]*(.+)\z/ ) {
                         # Action: failed
                         $v->{'action'} = lc $1;
 
-                    } elsif( $e =~ m/\A[Ss]tatus:[ ]*(\d[.]\d+[.]\d+)/ ) {
+                    } elsif( $e =~ /\AStatus:[ ]*(\d[.]\d+[.]\d+)/ ) {
                         # Status:5.2.0
                         $v->{'status'} = $1;
 
-                    } elsif( $e =~ m/\A[Rr]eporting-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
+                    } elsif( $e =~ /\AReporting-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
                         # Reporting-MTA: dns;BLU004-OMC3S13.hotmail.example.com
                         $connheader->{'lhost'} = lc $1;
 
-                    } elsif( $e =~ m/\A[Rr]eceived-[Ff]rom-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
+                    } elsif( $e =~ /\AReceived-From-MTA:[ ]*(?:DNS|dns);[ ]*(.+)\z/ ) {
                         # Reporting-MTA: dns;BLU004-OMC3S13.hotmail.example.com
                         $connheader->{'rhost'} = lc $1;
 
-                    } elsif( $e =~ m/\A[Aa]rrival-[Dd]ate:[ ]*(.+)\z/ ) {
+                    } elsif( $e =~ /\AArrival-Date:[ ]*(.+)\z/ ) {
                         # Arrival-Date: Wed, 29 Apr 2009 16:03:18 +0900
                         next if length $connheader->{'date'};
                         $connheader->{'date'} = $1;
 
                     } else {
-                        $htmlbegins = 1 if $e =~ m/\A[<]html[>]/;
+                        $htmlbegins = 1 if index($e, '<html>') == 0;
                     }
                 } else {
-                    if( $e =~ $Re1->{'error'} ) {
+                    if( $e eq $StartingOf->{'error'}->[0] ) {
                         # Diagnostic information for administrators:
                         $v->{'diagnosis'} = $e;
 
@@ -209,21 +204,21 @@ sub scan {
                         # Remote Server returned '550 5.1.10 RESOLVER.ADR.RecipientNotFound; Recipien=
                         # t not found by SMTP address lookup'
                         next unless $v->{'diagnosis'};
-                        if( $e =~ $Re1->{'eoerr'} ) {
+                        if( $e eq $StartingOf->{'eoerr'}->[0] ) {
                             # Original message headers:
                             $endoferror = 1;
                             next;
                         }
-                        $v->{'diagnosis'}  .= ' '.$e;
+                        $v->{'diagnosis'} .= ' '.$e;
                     }
                 }
             }
         } # End of if: rfc822
     }
     return undef unless $recipients;
+
     require Sisimai::String;
     require Sisimai::SMTP::Status;
-
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
         map { $e->{ $_ } ||= $connheader->{ $_ } || '' } keys %$connheader;
@@ -231,18 +226,18 @@ sub scan {
         $e->{'agent'}     = __PACKAGE__->smtpagent;
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
 
-        if( length($e->{'status'}) == 0 || $e->{'status'} =~ m/\A\d[.]0[.]0\z/ ) {
+        if( length($e->{'status'}) == 0 || substr($e->{'status'}, -4, 4) eq '.0.0' ) {
             # There is no value of Status header or the value is 5.0.0, 4.0.0
             my $r = Sisimai::SMTP::Status->find($e->{'diagnosis'});
             $e->{'status'} = $r if length $r;
         }
         next unless $e->{'status'};
 
-        # Find the error code from $CodeTable
-        for my $f ( keys %$CodeTable ) {
+        # Find the error code from $StatusList
+        for my $f ( keys %$StatusList ) {
             # Try to match with each key as a regular expression
             next unless $e->{'status'} =~ $f;
-            $e->{'reason'} = $CodeTable->{ $f };
+            $e->{'reason'} = $StatusList->{ $f };
             last;
         }
     }
@@ -293,7 +288,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2016-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
