@@ -4,26 +4,9 @@ use feature ':5.10';
 use strict;
 use warnings;
 
-my $Re0 = {
-    'received' => qr/by .+[.]vtext[.]com /,
-    'vtext.com' => {
-        'from' => qr/\Apost_master[@]vtext[.]com\z/,
-    },
-    'vzwpix.com' => {
-        'from'    => qr/[<]?sysadmin[@].+[.]vzwpix[.]com[>]?\z/,
-        'subject' => qr/Undeliverable Message/,
-    },
-};
 my $Indicators = __PACKAGE__->INDICATORS;
 
-sub pattern     { 
-    return {
-        'from' => qr/[<]?(?:\Apost_master[@]vtext|sysadmin[@].+[.]vzwpix)[.]com[>]?\z/,
-        'subject' => $Re0->{'vzwpix.com'}->{'subject'},
-    };
-}
 sub description { 'Verizon Wireless: http://www.verizonwireless.com' }
-
 sub scan {
     # Detect an error from Verizon
     # @param         [Hash] mhead       Message headers of a bounce email
@@ -44,9 +27,10 @@ sub scan {
 
     while(1) {
         # Check the value of "From" header
-        last unless grep { $_ =~ $Re0->{'received'} } @{ $mhead->{'received'} };
-        $match = 1 if $mhead->{'from'} =~ $Re0->{'vtext.com'}->{'from'};
-        $match = 0 if $mhead->{'from'} =~ $Re0->{'vzwpix.com'}->{'from'};
+        # 'subject' => qr/Undeliverable Message/,
+        last unless grep { index($_, '.vtext.com (') > -1 } @{ $mhead->{'received'} };
+        $match = 1 if $mhead->{'from'} eq 'post_master@vtext.com';
+        $match = 0 if $mhead->{'from'} =~ /[<]?sysadmin[@].+[.]vzwpix[.]com[>]?\z/;
         last;
     }
     return undef if $match < 0;
@@ -65,37 +49,35 @@ sub scan {
     my $senderaddr = '';    # (String) Sender address in the message body
     my $subjecttxt = '';    # (String) Subject of the original message
 
-    my $Re1        = {};    # (Ref->Hash) Delimiter patterns
-    my $ReFailure  = {};    # (Ref->Hash) Error message patterns
+    my $StartingOf = {};    # (Ref->Hash) Delimiter strings
+    my $MarkingsOf = {};    # (Ref->Hash) Delimiter patterns
+    my $ReFailures = {};    # (Ref->Hash) Error message patterns
     my $boundary00 = '';    # (String) Boundary string
     my $v = undef;
 
     if( $match == 1 ) {
         # vtext.com
-        $Re1 = {
-            'begin'  => qr/\AError:[ \t]/,
-            'rfc822' => qr/\A__BOUNDARY_STRING_HERE__\z/,
-            'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
+        $MarkingsOf = {
+            'message' => qr/\AError:[ \t]/,
+            'rfc822'  => qr/\A__BOUNDARY_STRING_HERE__\z/,
         };
-        $ReFailure = {
-            'userunknown' => qr{
-                # The attempted recipient address does not exist.
-                550[ ][-][ ]Requested[ ]action[ ]not[ ]taken:[ ]no[ ]such[ ]user[ ]here
-            }x,
+        $ReFailures = {
+            # The attempted recipient address does not exist.
+            'userunknown' => qr/550 [-] Requested action not taken: no such user here/,
         };
 
         $boundary00 = Sisimai::MIME->boundary($mhead->{'content-type'});
         if( length $boundary00 ) {
             # Convert to regular expression
             $boundary00 = '--'.$boundary00.'--';
-            $Re1->{'rfc822'} = qr/\A\Q$boundary00\E\z/; 
+            $MarkingsOf->{'rfc822'} = qr/\A\Q$boundary00\E\z/; 
         }
 
         for my $e ( @hasdivided ) {
-            # Read each line between $Re0->{'begin'} and $Re0->{'rfc822'}.
+            # Read each line between the start of the message and the start of rfc822 part.
             unless( $readcursor ) {
                 # Beginning of the bounce message or delivery status part
-                if( $e =~ $Re1->{'begin'} ) {
+                if( $e =~ $MarkingsOf->{'message'} ) {
                     $readcursor |= $Indicators->{'deliverystatus'};
                     next;
                 }
@@ -103,7 +85,7 @@ sub scan {
 
             unless( $readcursor & $Indicators->{'message-rfc822'} ) {
                 # Beginning of the original message part
-                if( $e =~ $Re1->{'rfc822'} ) {
+                if( $e =~ $MarkingsOf->{'rfc822'} ) {
                     $readcursor |= $Indicators->{'message-rfc822'};
                     next;
                 }
@@ -130,7 +112,7 @@ sub scan {
                 #   RCPT TO: *****@vtext.com
                 $v = $dscontents->[-1];
 
-                if( $e =~ m/\A[ \t]+RCPT TO: (.*)\z/ ) {
+                if( $e =~ /\A[ \t]+RCPT TO: (.*)\z/ ) {
                     if( length $v->{'recipient'} ) {
                         # There are multiple recipient addresses in the message body.
                         push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
@@ -140,45 +122,38 @@ sub scan {
                     $recipients++;
                     next;
 
-                } elsif( $e =~ m/\A[ \t]+MAIL FROM:[ \t](.+)\z/ ) {
+                } elsif( $e =~ /\A[ \t]+MAIL FROM:[ \t](.+)\z/ ) {
                     #   MAIL FROM: *******@hg.example.com
                     $senderaddr ||= $1;
 
-                } elsif( $e =~ m/\A[ \t]+Subject:[ \t](.+)\z/ ) {
+                } elsif( $e =~ /\A[ \t]+Subject:[ \t](.+)\z/ ) {
                     #   Subject:
                     $subjecttxt ||= $1;
 
                 } else {
                     # 550 - Requested action not taken: no such user here
-                    $v->{'diagnosis'} = $e if $e =~ m/\A(\d{3})[ \t][-][ \t](.*)\z/;
+                    $v->{'diagnosis'} = $e if $e =~ /\A(\d{3})[ \t][-][ \t](.*)\z/;
                 }
             } # End of if: rfc822
         }
     } else {
         # vzwpix.com
-        $Re1 = {
-            'begin'  => qr/\AMessage could not be delivered to mobile/,
-            'rfc822' => qr/\A__BOUNDARY_STRING_HERE__\z/,
-            'endof'  => qr/\A__END_OF_EMAIL_MESSAGE__\z/,
-        };
-        $ReFailure = {
-            'userunknown' => qr{
-                No[ ]valid[ ]recipients[ ]for[ ]this[ ]MM
-            }x,
-        };
+        $StartingOf = { 'message' => ['Message could not be delivered to mobile'] };
+        $MarkingsOf = { 'rfc822'  => qr/\A__BOUNDARY_STRING_HERE__\z/ };
+        $ReFailures = { 'userunknown' => qr/No valid recipients for this MM/ };
 
         $boundary00 = Sisimai::MIME->boundary($mhead->{'content-type'});
         if( length $boundary00 ) {
             # Convert to regular expression
             $boundary00 = '--'.$boundary00.'--';
-            $Re1->{'rfc822'} = qr/\A\Q$boundary00\E\z/; 
+            $MarkingsOf->{'rfc822'} = qr/\A\Q$boundary00\E\z/; 
         }
 
         for my $e ( @hasdivided ) {
-            # Read each line between $Re0->{'begin'} and $Re0->{'rfc822'}.
+            # Read each line between the start of the message and the start of rfc822 part.
             unless( $readcursor ) {
                 # Beginning of the bounce message or delivery status part
-                if( $e =~ $Re1->{'begin'} ) {
+                if( index($e, $StartingOf->{'message'}->[0]) == 0 ) {
                     $readcursor |= $Indicators->{'deliverystatus'};
                     next;
                 }
@@ -186,7 +161,7 @@ sub scan {
 
             unless( $readcursor & $Indicators->{'message-rfc822'} ) {
                 # Beginning of the original message part
-                if( $e =~ $Re1->{'rfc822'} ) {
+                if( $e =~ $MarkingsOf->{'rfc822'} ) {
                     $readcursor |= $Indicators->{'message-rfc822'};
                     next;
                 }
@@ -213,7 +188,7 @@ sub scan {
                 # Date:  Wed, 20 Jun 2013 10:29:52 +0000
                 $v = $dscontents->[-1];
 
-                if( $e =~ m/\ATo:[ \t]+(.*)\z/ ) {
+                if( $e =~ /\ATo:[ \t]+(.*)\z/ ) {
                     if( length $v->{'recipient'} ) {
                         # There are multiple recipient addresses in the message body.
                         push @$dscontents, __PACKAGE__->DELIVERYSTATUS;
@@ -223,40 +198,40 @@ sub scan {
                     $recipients++;
                     next;
 
-                } elsif( $e =~ m/\AFrom:[ \t](.+)\z/ ) {
+                } elsif( $e =~ /\AFrom:[ \t](.+)\z/ ) {
                     # From: kijitora <kijitora@example.jp>
                     $senderaddr ||= Sisimai::Address->s3s4($1);
 
-                } elsif( $e =~ m/\ASubject:[ \t](.+)\z/ ) {
+                } elsif( $e =~ /\ASubject:[ \t](.+)\z/ ) {
                     #   Subject:
                     $subjecttxt ||= $1;
 
                 } else {
                     # Message could not be delivered to mobile.
                     # Error: No valid recipients for this MM
-                    $v->{'diagnosis'} = $e if $e =~ m/\AError:[ \t]+(.+)\z/;
+                    $v->{'diagnosis'} = $e if $e =~ /\AError:[ \t]+(.+)\z/;
                 }
             } # End of if: rfc822
         }
     }
     return undef unless $recipients;
 
-    if( ! grep { $_ =~ /^From: / } @$rfc822list ) {
+    if( ! grep { index($_, 'From: ') == 0 } @$rfc822list ) {
         # Set the value of "MAIL FROM:" or "From:"
-        push @$rfc822list, sprintf("From: %s", $senderaddr);
+        push @$rfc822list, 'From: '.$senderaddr;
 
-    } elsif( ! grep { $_ =~ /^Subject: / } @$rfc822list ) {
+    } elsif( ! grep { index($_, 'Subject: ') == 0 } @$rfc822list ) {
         # Set the value of "Subject"
-        push @$rfc822list, sprintf("Subject: %s", $subjecttxt);
+        push @$rfc822list, 'Subject: '.$subjecttxt;
     }
 
     for my $e ( @$dscontents ) {
         $e->{'agent'}     = __PACKAGE__->smtpagent;
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
 
-        SESSION: for my $r ( keys %$ReFailure ) {
+        SESSION: for my $r ( keys %$ReFailures ) {
             # Verify each regular expression of session errors
-            next unless $e->{'diagnosis'} =~ $ReFailure->{ $r };
+            next unless $e->{'diagnosis'} =~ $ReFailures->{ $r };
             $e->{'reason'} = $r;
             last;
         }
@@ -309,7 +284,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
