@@ -16,10 +16,10 @@ sub match {
 
     # Destination mail server does not accept any message
     my $regex = qr{(?:
-         Name[ ]server:[ ][.]:[ ]host[ ]not[ ]found # Sendmail
+         name[ ]server:[ ][.]:[ ]host[ ]not[ ]found # Sendmail
         |55[46][ ]smtp[ ]protocol[ ]returned[ ]a[ ]permanent[ ]error
         )
-    }ix;
+    }x;
 
     return 1 if $argv1 =~ $regex;
     return 0;
@@ -36,26 +36,13 @@ sub true {
     my $argvs = shift // return undef;
 
     return undef unless ref $argvs eq 'Sisimai::Data';
-    my $reasontext = __PACKAGE__->text;
+    return 1 if $argvs->reason eq 'notaccept';
 
-    return 1 if $argvs->reason eq $reasontext;
-
-    my $diagnostic = $argvs->diagnosticcode // '';
-    my $v = 0;
-
-    if( $argvs->replycode =~ m/\A(?:521|554|556)\z/ ) {
-        # SMTP Reply Code is 554 or 556
-        $v = 1;
-
-    } else {
-        # Check the value of Diagnosic-Code: header with patterns
-        if( $argvs->smtpcommand eq 'MAIL' ) {
-            # Matched with a pattern in this class
-            $v = 1 if __PACKAGE__->match($diagnostic);
-        }
-    }
-
-    return $v;
+    # SMTP Reply Code is 521, 554 or 556
+    return 1 if $argvs->replycode =~ /\A(?:521|554|556)\z/;
+    return 0 unless $argvs->smtpcommand eq 'MAIL';
+    return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
+    return 0;
 }
 
 1;
@@ -107,7 +94,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
