@@ -14,43 +14,43 @@ sub match {
     my $class = shift;
     my $argv1 = shift // return undef;
     my $isnot = qr{(?:
-         5[.]1[.]0[ ]Address
-        |Recipient[ ]address
-        |Sender[ ]IP[ ]address
+         5[.]1[.]0[ ]address
+        |recipient[ ]address
+        |sender[ ]ip[ ]address
         )[ ]rejected
-    }xi;
+    }x;
     my $regex = qr{(?>
          [<][>][ ]invalid[ ]sender
         |address[ ]rejected
-        |Administrative[ ]prohibition
+        |administrative[ ]prohibition
         |batv[ ](?:
              failed[ ]to[ ]verify   # SoniWall
             |validation[ ]failure   # SoniWall
             )
         |backscatter[ ]protection[ ]detected[ ]an[ ]invalid[ ]or[ ]expired[ ]email[ ]address    # MDaemon
         |bogus[ ]mail[ ]from        # IMail - block empty sender
-        |Connections[ ]not[ ]accepted[ ]from[ ]servers[ ]without[ ]a[ ]valid[ ]sender[ ]domain
+        |connections[ ]not[ ]accepted[ ]from[ ]servers[ ]without[ ]a[ ]valid[ ]sender[ ]domain
         |denied[ ]\[bouncedeny\]    # McAfee
-        |Delivery[ ]not[ ]authorized,[ ]message[ ]refused
-        |does[ ]not[ ]exist[ ]E2110
+        |delivery[ ]not[ ]authorized,[ ]message[ ]refused
+        |does[ ]not[ ]exist[ ]e2110
         |domain[ ]of[ ]sender[ ]address[ ].+[ ]does[ ]not[ ]exist
-        |Emetteur[ ]invalide.+[A-Z]{3}.+(?:403|405|415)
+        |emetteur[ ]invalide.+[a-z]{3}.+(?:403|405|415)
         |empty[ ]envelope[ ]senders[ ]not[ ]allowed
         |error:[ ]no[ ]third-party[ ]dsns               # SpamWall - block empty sender
-        |From:[ ]Domain[ ]is[ ]invalid[.][ ]Please[ ]provide[ ]a[ ]valid[ ]From:
+        |from:[ ]domain[ ]is[ ]invalid[.][ ]please[ ]provide[ ]a[ ]valid[ ]from:
         |fully[ ]qualified[ ]email[ ]address[ ]required # McAfee
         |invalid[ ]domain,[ ]see[ ][<]url:.+[>]
-        |Mail[ ]from[ ]not[ ]owned[ ]by[ ]user.+[A-Z]{3}.+421
-        |Message[ ]rejected:[ ]Email[ ]address[ ]is[ ]not[ ]verified
+        |mail[ ]from[ ]not[ ]owned[ ]by[ ]user.+[a-z]{3}.+421
+        |message[ ]rejected:[ ]email[ ]address[ ]is[ ]not[ ]verified
         |mx[ ]records[ ]for[ ].+[ ]violate[ ]section[ ].+
-        |Null[ ]Sender[ ]is[ ]not[ ]allowed
+        |null[ ]sender[ ]is[ ]not[ ]allowed
         |recipient[ ]not[ ]accepted[.][ ][(]batv:[ ]no[ ]tag
         |returned[ ]mail[ ]not[ ]accepted[ ]here
         |rfc[ ]1035[ ]violation:[ ]recursive[ ]cname[ ]records[ ]for
         |rule[ ]imposed[ ]mailbox[ ]access[ ]for        # MailMarshal
         |sender[ ](?:
              email[ ]address[ ]rejected
-            |is[ ]Spammer
+            |is[ ]spammer
             |not[ ]pre[-]approved
             |rejected
             |domain[ ]is[ ]empty
@@ -59,10 +59,10 @@ sub match {
         |syntax[ ]error:[ ]empty[ ]email[ ]address
         |the[ ]message[ ]has[ ]been[ ]rejected[ ]by[ ]batv[ ]defense
         |transaction[ ]failed[ ]unsigned[ ]dsn[ ]for
-        |Unroutable[ ]sender[ ]address
+        |unroutable[ ]sender[ ]address
         |you[ ]are[ ]sending[ ]to[/]from[ ]an[ ]address[ ]that[ ]has[ ]been[ ]blacklisted
         )
-    }xi;
+    }x;
 
     return 0 if $argv1 =~ $isnot;
     return 1 if $argv1 =~ $regex;
@@ -82,40 +82,29 @@ sub true {
     return undef unless ref $argvs eq 'Sisimai::Data';
     require Sisimai::SMTP::Status;
 
-    my $statuscode = $argvs->deliverystatus // '';
-    my $reasontext = __PACKAGE__->text;
-    my $tempreason = Sisimai::SMTP::Status->name($statuscode) || 'undefined';
+    my $tempreason = Sisimai::SMTP::Status->name($argvs->deliverystatus) || 'undefined';
+    my $diagnostic = lc $argvs->diagnosticcode;
 
-    return 1 if $argvs->reason eq $reasontext;
+    return 1 if $argvs->reason eq 'rejected';
+    return 1 if $tempreason eq 'rejected';  # Delivery status code points "rejected".
 
-    my $diagnostic = $argvs->diagnosticcode // '';
-    my $v = 0;
+    # Check the value of Diagnosic-Code: header with patterns
+    if( $argvs->smtpcommand eq 'MAIL' ) {
+        # The session was rejected at 'MAIL FROM' command
+        return 1 if __PACKAGE__->match($diagnostic);
 
-    if( $tempreason eq $reasontext ) {
-        # Delivery status code points "rejected".
-        $v = 1;
-    } else {
-        # Check the value of Diagnosic-Code: header with patterns
-        if( $argvs->smtpcommand eq 'MAIL' ) {
-            # The session was rejected at 'MAIL FROM' command
-            $v = 1 if __PACKAGE__->match($diagnostic);
-
-        } elsif( $argvs->smtpcommand eq 'DATA' ) {
-            # The session was rejected at 'DATA' command
-            if( $tempreason ne 'userunknown' ) {
-                # Except "userunknown"
-                $v = 1 if __PACKAGE__->match($diagnostic);
-            }
-        } else {
-            if( $tempreason =~ /\A(?:onhold|undefined|securityerror|systemerror)\z/ ) {
-                # Try to match with message patterns when the temporary reason
-                # is "onhold", "undefined", "securityerror", or "systemerror"
-                $v = 1 if __PACKAGE__->match($diagnostic);
-            }
+    } elsif( $argvs->smtpcommand eq 'DATA' ) {
+        # The session was rejected at 'DATA' command
+        if( $tempreason ne 'userunknown' ) {
+            # Except "userunknown"
+            return 1 if __PACKAGE__->match($diagnostic);
         }
+    } elsif( $tempreason =~ /\A(?:onhold|undefined|securityerror|systemerror)\z/ ) {
+        # Try to match with message patterns when the temporary reason
+        # is "onhold", "undefined", "securityerror", or "systemerror"
+        return 1 if __PACKAGE__->match($diagnostic);
     }
-
-    return $v;
+    return 0;
 }
 
 1;
@@ -171,7 +160,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
