@@ -14,7 +14,7 @@ sub match {
     my $class = shift;
     my $argv1 = shift // return undef;
     my $regex = qr{(?>
-         Boite[ ]du[ ]destinataire[ ]archivee.+[A-Z]{3}.+420
+         boite[ ]du[ ]destinataire[ ]archivee.+[a-z]{3}.+420
         |email[ ]account[ ]that[ ]you[ ]tried[ ]to[ ]reach[ ]is[ ]disabled
         |invalid/inactive[ ]user
         # http://service.mail.qq.com/cgi-bin/help?subtype=1&&id=20022&&no=1000742
@@ -24,17 +24,17 @@ sub match {
             |unavailable[ ]or[ ]access[ ]denied
             )
         |recipient[ ](?:
-             rejected:[ ]Temporarily[ ]inactive
+             rejected:[ ]temporarily[ ]inactive
             |suspend[ ]the[ ]service
             )
         |sorry[ ]your[ ]message[ ]to[ ].+[ ]cannot[ ]be[ ]delivered[.][ ]this[ ]
             account[ ]has[ ]been[ ]disabled[ ]or[ ]discontinued
-        |The[ ]domain[ ].+[ ]is[ ]currently[ ]suspended
-        |User[ ].+[ ]temporary[ ]locked
+        |the[ ]domain[ ].+[ ]is[ ]currently[ ]suspended
+        |user[ ].+[ ]temporary[ ]locked
         |user[ ]suspended   # http://mail.163.com/help/help_spam_16.htm
         |vdelivermail:[ ]account[ ]is[ ]locked[ ]email[ ]bounced
         )
-    }xi;
+    }x;
 
     return 1 if $argv1 =~ $regex;
     return 0;
@@ -51,12 +51,10 @@ sub true {
     my $argvs = shift // return undef;
 
     return undef unless ref $argvs eq 'Sisimai::Data';
-    my $statuscode = $argvs->deliverystatus // '';
-    my $reasontext = __PACKAGE__->text;
+    return undef unless $argvs->deliverystatus;
 
-    return undef unless length $statuscode;
-    return 1 if $argvs->reason eq $reasontext;
-    return 1 if __PACKAGE__->match($argvs->diagnosticcode // '');
+    return 1 if $argvs->reason eq 'suspend';
+    return 1 if __PACKAGE__->match(lc $argvs->diagnosticcode);
     return 0
 }
 
@@ -107,7 +105,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
