@@ -17,13 +17,13 @@ sub match {
          .+[ ]user[ ]unknown
         |[#]5[.]1[.]1[ ]bad[ ]address
         |[<].+[>][ ]not[ ]found
-        |[<].+[@].+[>][.][.][.][ ]Blocked[ ]by[ ]
-        |5[.]0[.]0[.][ ]Mail[ ]rejected[.]
-        |5[.]1[.]0[ ]Address[ ]rejected[.]
-        |Adresse[ ]d[ ]au[ ]moins[ ]un[ ]destinataire[ ]invalide.+[A-Z]{3}.+(?:416|418)
+        |[<].+[@].+[>][.][.][.][ ]blocked[ ]by[ ]
+        |5[.]0[.]0[.][ ]mail[ ]rejected[.]
+        |5[.]1[.]0[ ]address[ ]rejected[.]
+        |adresse[ ]d[ ]au[ ]moins[ ]un[ ]destinataire[ ]invalide.+[a-z]{3}.+(?:416|418)
         |address[ ](?:does[ ]not[ ]exist|unknown)
         |archived[ ]recipient
-        |BAD[-_ \t]RECIPIENT
+        |bad[-_ \t]recipient
         |can[']t[ ]accept[ ]user
         |destination[ ](?:
              addresses[ ]were[ ]unknown
@@ -65,7 +65,7 @@ sub match {
                 |recipient
                 |user(?:[ ]here)?
                 )
-            |thank[ ]you[ ]rejected:[ ]Account[ ]Unavailable:
+            |thank[ ]you[ ]rejected:[ ]account[ ]unavailable:
             |valid[ ]recipients[,][ ]bye    # Microsoft
             )
         |non[- ]?existent[ ]user
@@ -78,7 +78,7 @@ sub match {
         |rece?ipient[ ](?:
              .+[ ]was[ ]not[ ]found[ ]in
             |address[ ]rejected:[ ](?:
-                 Access[ ]denied
+                 access[ ]denied
                 |invalid[ ]user
                 |user[ ].+[ ]does[ ]not[ ]exist
                 |user[ ]unknown[ ]in[ ].+[ ]table
@@ -86,13 +86,13 @@ sub match {
                 )
             |does[ ]not[ ]exist(?:[ ]on[ ]this[ ]system)?
             |is[ ]not[ ]local
-            |not[ ](?:exist|found|OK)
+            |not[ ](?:exist|found|ok)
             |unknown
             )
         |requested[ ]action[ ]not[ ]taken:[ ]mailbox[ ]unavailable
-        |RESOLVER[.]ADR[.]Recip(?:ient)NotFound # Microsoft
+        |resolver[.]adr[.]recip(?:ient)notfound # Microsoft
         |said:[ ]550[-[ ]]5[.]1[.]1[ ].+[ ]user[ ]unknown[ ]
-        |SMTP[ ]error[ ]from[ ]remote[ ]mail[ ]server[ ]after[ ]end[ ]of[ ]data:[ ]553.+does[ ]not[ ]exist
+        |smtp[ ]error[ ]from[ ]remote[ ]mail[ ]server[ ]after[ ]end[ ]of[ ]data:[ ]553.+does[ ]not[ ]exist
         |sorry,[ ](?:
              user[ ]unknown
             |badrcptto
@@ -103,7 +103,7 @@ sub match {
             |following[ ]recipients[ ]was[ ]undeliverable
             |user[']s[ ]email[ ]name[ ]is[ ]not[ ]found
             )
-        |There[ ]is[ ]no[ ]one[ ]at[ ]this[ ]address
+        |there[ ]is[ ]no[ ]one[ ]at[ ]this[ ]address
         |this[ ](?:
              address[ ]no[ ]longer[ ]accepts[ ]mail
             |email[ ]address[ ]is[ ]wrong[ ]or[ ]no[ ]longer[ ]valid
@@ -128,7 +128,7 @@ sub match {
         |vdeliver:[ ]invalid[ ]or[ ]unknown[ ]virtual[ ]user
         |your[ ]envelope[ ]recipient[ ]is[ ]in[ ]my[ ]badrcptto[ ]list
         )
-    }xi;
+    }x;
 
     return 1 if $argv1 =~ $regex;
     return 0;
@@ -145,28 +145,22 @@ sub true {
     my $argvs = shift // return undef;
 
     return undef unless ref $argvs eq 'Sisimai::Data';
-    return 1 if $argvs->reason eq __PACKAGE__->text;
+    return 1 if $argvs->reason eq 'userunknown';
 
     require Sisimai::SMTP::Status;
-    my $prematches = [
-        'NoRelaying', 'Blocked', 'MailboxFull', 'HasMoved',
-        'Blocked', 'Rejected',
-    ];
-    my $matchother = 0;
-    my $statuscode = $argvs->deliverystatus // '';
-    my $diagnostic = $argvs->diagnosticcode // '';
-    my $tempreason = Sisimai::SMTP::Status->name($statuscode);
-    my $reasontext = __PACKAGE__->text;
-    my $v = 0;
-
+    my $diagnostic = lc $argvs->diagnosticcode;
+    my $tempreason = Sisimai::SMTP::Status->name($argvs->deliverystatus);
     return 0 if $tempreason eq 'suspend';
 
-    if( $tempreason eq $reasontext ) {
+    if( $tempreason eq 'userunknown' ) {
         # *.1.1 = 'Bad destination mailbox address'
         #   Status: 5.1.1
         #   Diagnostic-Code: SMTP; 550 5.1.1 <***@example.jp>:
         #     Recipient address rejected: User unknown in local recipient table
+        my $prematches = [qw|NoRelaying Blocked MailboxFull HasMoved Blocked Rejected|];
+        my $matchother = 0;
         require Module::Load;
+
         for my $e ( @$prematches ) {
             # Check the value of "Diagnostic-Code" with other error patterns.
             my $p = 'Sisimai::Reason::'.$e;
@@ -177,20 +171,14 @@ sub true {
             $matchother = 1;
             last;
         }
+        return 1 if $matchother == 0;   # Did not match with other message patterns
 
-        # Did not match with other message patterns
-        $v = 1 if $matchother == 0;
-
-    } else {
-        # Check the last SMTP command of the session. 
-        if( $argvs->smtpcommand eq 'RCPT' ) {
-            # When the SMTP command is not "RCPT", the session rejected by other
-            # reason, maybe.
-            $v = 1 if __PACKAGE__->match($diagnostic);
-        }
+    } elsif( $argvs->smtpcommand eq 'RCPT' ) {
+        # When the SMTP command is not "RCPT", the session rejected by other
+        # reason, maybe.
+        return 1 if __PACKAGE__->match($diagnostic);
     }
-
-    return $v;
+    return 0;
 }
 
 1;
@@ -248,7 +236,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
