@@ -6,15 +6,12 @@ use Sisimai::SMTP::Reply;
 use Sisimai::SMTP::Status;
 
 my $SoftOrHard = {
-    'soft' => [
-        'blocked', 'contenterror', 'exceedlimit', 'expired', 'filtered',
-        'mailboxfull', 'mailererror', 'mesgtoobig', 'networkerror', 'norelaying',
-        'policyviolation', 'rejected', 'securityerror', 'spamdetected', 'suspend',
-        'syntaxerror', 'systemerror', 'systemfull', 'toomanyconn', 'virusdetected',
-    ],
-    'hard' => [
-        'hasmoved', 'hostunknown', 'userunknown',
-    ],
+    'soft' => [qw|
+        blocked contenterror exceedlimit expired filtered mailboxfull mailererror
+        mesgtoobig networkerror norelaying policyviolation rejected securityerror
+        spamdetected suspend syntaxerror systemerror systemfull toomanyconn virusdetected
+    |],
+    'hard' => [qw|hasmoved hostunknown userunknown|],
 };
 
 sub is_permanent {
@@ -27,14 +24,11 @@ sub is_permanent {
     my $class = shift;
     my $argv1 = shift || return undef;
 
-    my $statuscode = undef;
-    my $classvalue = undef;
+    my $statuscode   = Sisimai::SMTP::Status->find($argv1);
+       $statuscode ||= Sisimai::SMTP::Reply->find($argv1);
+    my $classvalue   = int(substr($statuscode, 0, 1) || 0);
     my $getchecked = undef;
 
-    $statuscode   = Sisimai::SMTP::Status->find($argv1);
-    $statuscode ||= Sisimai::SMTP::Reply->find($argv1);
-    $classvalue   = int(substr($statuscode, 0, 1) || 0);
-
     if( $classvalue > 0 ) {
         # 2, 4, or 5
         if( $classvalue == 5 ) {
@@ -51,11 +45,12 @@ sub is_permanent {
         }
     } else {
         # Check with regular expression
-        if( $argv1 =~ m/(?:temporar|persistent)/i ) {
+        my $v = lc $argv1;
+        if( index($v, 'temporar') > -1 || index($v, 'persistent') > -1 ) {
             # Temporary failure
             $getchecked = 0;
 
-        } elsif( $argv1 =~ m/permanent/i ) {
+        } elsif( index($v, 'permanent') > -1 ) {
             # Permanently failure
             $getchecked = 1;
 
@@ -85,7 +80,7 @@ sub soft_or_hard {
     my $classvalue = undef;
     my $softorhard = undef;
 
-    if( $argv1 =~ m/\A(?:delivered|feedback|vacation)\z/ ) {
+    if( $argv1 eq 'deliverd' || $argv1 eq 'feedback' || $argv1 eq 'vacation' ) {
         # These are not dealt as a bounce reason
         $softorhard = '';
 
@@ -108,14 +103,8 @@ sub soft_or_hard {
             $statuscode   = Sisimai::SMTP::Status->find($argv2);
             $statuscode ||= Sisimai::SMTP::Reply->find($argv2);
             $classvalue   = int(substr($statuscode, 0, 1) || 0);
+            $softorhard   = $classvalue == 4 ? 'soft' : 'hard';
 
-            if( $classvalue == 4 ) {
-                # Deal as a "soft bounce"
-                $softorhard = 'soft';
-            } else {
-                # 5 or 0, deal as a "hard bounce"
-                $softorhard = 'hard';
-            }
         } else {
             # "notaccept" is a hard bounce
             $softorhard = 'hard';
@@ -132,7 +121,6 @@ sub soft_or_hard {
             }
         }
     }
-
     $softorhard //= '';
     return $softorhard;
 }
@@ -182,7 +170,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2016-2017 azumakuniyuki, All rights reserved.
+Copyright (C) 2016-2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
