@@ -42,7 +42,7 @@ sub is_8bit {
 
     return undef unless ref $argv1;
     return undef unless ref $argv1 eq 'SCALAR';
-    return 1 unless $$argv1 =~ m/\A[\x00-\x7f]+\z/;
+    return 1 unless $$argv1 =~ /\A[\x00-\x7f]+\z/;
     return 0;
 }
 
@@ -56,12 +56,11 @@ sub sweep {
     my $argv1 = shift // return undef;
 
     chomp $argv1;
-    $argv1 =~ y{ }{}s;
-    $argv1 =~ s{\t}{}g;
-    $argv1 =~ s{\A }{}g;
-    $argv1 =~ s{ \z}{}g;
-    $argv1 =~ s{ [-]{2,}[^ \t].+\z}{};
-
+    $argv1 =~ y/ //s;
+    $argv1 =~ y/\t//d;
+    $argv1 =~ s/\A //g;
+    $argv1 =~ s/ \z//g;
+    $argv1 =~ s/ [-]{2,}[^ \t].+\z//;
     return $argv1;
 }
 
@@ -117,11 +116,11 @@ sub to_utf8 {
     my $argv2 = shift;
 
     my $tobeutf8ed = $$argv1;
-    my $encodefrom = $argv2 || '';
+    my $encodefrom = lc $argv2 || '';
     my $hasencoded = undef;
     my $hasguessed = Encode::Guess->guess($tobeutf8ed);
-    my $encodingto = ref $hasguessed ? $hasguessed->name : '';
-    my $dontencode = qr/\A(?>utf[-]?8|(?:us[-])?ascii)\z/i;
+    my $encodingto = ref $hasguessed ? lc($hasguessed->name) : '';
+    my $dontencode = qr/\A(?>utf[-]?8|(?:us[-])?ascii)\z/;
 
     if( length $encodefrom ) {
         # The 2nd argument is a encoding name of the 1st argument
@@ -230,7 +229,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2016 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2016,2018 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
